<?php

namespace Modules\Qc\Http\Controllers;

use Exception;
use Illuminate\Contracts\Support\Renderable;
use Illuminate\Http\Request;
use Illuminate\Routing\Controller;
use Modules\Qc\Entities\MaterialType;

class SettingsController extends Controller
{
    public function disableMaterialType(Request $request, $id)
    {
        try {
            $status = $request->get('status');
            $object = MaterialType::find($id);
            $object->status = $status;
            $update = $object->save();
            if ($update) {
                $responseBody = $this->responseBody(true, "disableMaterialType", "updated", null);
            }
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "disableMaterialType", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }

    public function updateMaterialType(Request $request, $id)
    {

        try {
            $material = MaterialType::find($id);
            $material->material_name = $request->get('material_name');
            $material->update();
            $responseBody = $this->responseBody(true, "SettingsController", "updateMaterialType", true);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "SettingsController", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }

    public function saveMaterialType(Request $request)
    {
        try {
            $object = new MaterialType();
            $object->material_name = $request->get('material_name');
            $object->status = true;
            $save = $object->save();

            if ($save) {
                $responseBody = $this->responseBody(true, "saveMaterialType", "saved", true);
            }
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "saveMaterialType", "error", $exception);
        }
        return response()->json(["data" => $responseBody]);
    }

    public function getAllMaterialType()
    {
        try {
            $materials = MaterialType::all();
            $responseBody = $this->responseBody(true, "SettingsController", "getAllMaterialType", $materials);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "SettingsController", "error", null);
        }
        return response()->json(["data" => $responseBody]);
    }

    public function getMaterialType($id)
    {
        try {
            $material = MaterialType::find($id);
            $responseBody = $this->responseBody(true, "SettingsController", "getMaterialType", $material);
        } catch (Exception $exception) {
            $responseBody = $this->responseBody(false, "SettingsController", "error", null);
        }
        return response()->json(["data" => $responseBody]);
    }



    /**
     * responseBody
     * This is used to create response.
     * @param success This is the paramter require boolean
     * @param name This is the paramter require ui table name
     * @param message This is the paramter require message content
     * @param result This is the paramter require result as some of data to return client
     * @return Json This returns as response.
     */
    private function responseBody($success, $name, $message, $result)
    {
        $body = [
            "success" => $success,
            "message" => $message,
            "name" => $name,
            "result" => $result
        ];
        return $body;
    }

}
